PPAddress class abstract

Use for ApprovalData

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

PPAddress({bool? isPrimary, String? fullAddress, String? addressId, String? line1, String? line2, String? city, String? state, String? postalCode, String? country, bool? isSelected})
const
factory
PPAddress.fromJson(Map<String, dynamic> json)
factory

Properties

addressId String?
no setterinherited
city String?
no setterinherited
copyWith → $PPAddressCopyWith<PPAddress>
Create a copy of PPAddress with the given fields replaced by the non-null parameter values.
no setterinherited
country String?
no setterinherited
fullAddress String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isPrimary bool?
no setterinherited
isSelected bool?
no setterinherited
line1 String?
no setterinherited
line2 String?
no setterinherited
postalCode String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
no setterinherited

Methods

debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
map<TResult extends Object?>(TResult $default(_EPAddress value)) → TResult

Available on PPAddress, provided by the PPAddressPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EPAddress value)?) → TResult?

Available on PPAddress, provided by the PPAddressPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EPAddress value)?, {required TResult orElse()}) → TResult

Available on PPAddress, provided by the PPAddressPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool? isPrimary, String? fullAddress, String? addressId, String? line1, String? line2, String? city, String? state, String? postalCode, String? country, bool? isSelected)?, {required TResult orElse()}) → TResult

Available on PPAddress, provided by the PPAddressPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toJson() Map<String, dynamic>
Serializes this PPAddress to a JSON map.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
when<TResult extends Object?>(TResult $default(bool? isPrimary, String? fullAddress, String? addressId, String? line1, String? line2, String? city, String? state, String? postalCode, String? country, bool? isSelected)) → TResult

Available on PPAddress, provided by the PPAddressPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool? isPrimary, String? fullAddress, String? addressId, String? line1, String? line2, String? city, String? state, String? postalCode, String? country, bool? isSelected)?) → TResult?

Available on PPAddress, provided by the PPAddressPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited