PPAmountPatterns extension

Adds pattern-matching-related methods to PPAmount.

on

Methods

map<TResult extends Object?>(TResult $default(_Amount value)) → TResult

Available on PPAmount, provided by the PPAmountPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Amount value)?) → TResult?

Available on PPAmount, provided by the PPAmountPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Amount value)?, {required TResult orElse()}) → TResult

Available on PPAmount, provided by the PPAmountPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? currencyFormat, String? currencyFormatSymbolISOCurrency, String? currencyCode, String? currencySymbol, String? currencyValue)?, {required TResult orElse()}) → TResult

Available on PPAmount, provided by the PPAmountPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? currencyFormat, String? currencyFormatSymbolISOCurrency, String? currencyCode, String? currencySymbol, String? currencyValue)) → TResult

Available on PPAmount, provided by the PPAmountPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? currencyFormat, String? currencyFormatSymbolISOCurrency, String? currencyCode, String? currencySymbol, String? currencyValue)?) → TResult?

Available on PPAmount, provided by the PPAmountPatterns extension

A variant of when that fallback to returning null