PPApprovalData class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

PPApprovalData({String? payerId, String? orderId, String? paymentId, PPBuyer? payer, PPCart? cart, PPVaultData? vaultData})
const
factory
PPApprovalData.fromJson(Map<String, dynamic> json)
factory

Properties

cart PPCart?
no setterinherited
copyWith → $PPApprovalDataCopyWith<PPApprovalData>
Create a copy of PPApprovalData with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
orderId String?
no setterinherited
payer PPBuyer?
no setterinherited
payerId String?
no setterinherited
paymentId String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vaultData PPVaultData?
no setterinherited

Methods

debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
map<TResult extends Object?>(TResult $default(_PPApprovalData value)) → TResult

Available on PPApprovalData, provided by the PPApprovalDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PPApprovalData value)?) → TResult?

Available on PPApprovalData, provided by the PPApprovalDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PPApprovalData value)?, {required TResult orElse()}) → TResult

Available on PPApprovalData, provided by the PPApprovalDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? payerId, String? orderId, String? paymentId, PPBuyer? payer, PPCart? cart, PPVaultData? vaultData)?, {required TResult orElse()}) → TResult

Available on PPApprovalData, provided by the PPApprovalDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toJson() Map<String, dynamic>
Serializes this PPApprovalData to a JSON map.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
when<TResult extends Object?>(TResult $default(String? payerId, String? orderId, String? paymentId, PPBuyer? payer, PPCart? cart, PPVaultData? vaultData)) → TResult

Available on PPApprovalData, provided by the PPApprovalDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? payerId, String? orderId, String? paymentId, PPBuyer? payer, PPCart? cart, PPVaultData? vaultData)?) → TResult?

Available on PPApprovalData, provided by the PPApprovalDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited