toString method

  1. @override
String toString({
  1. DiagnosticLevel minLevel = DiagnosticLevel.info,
})
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) {
  return 'PPCart(cartId: $cartId, intent: $intent, billingType: $billingType, paymentId: $paymentId, billingToken: $billingToken, items: $items, amounts: $amounts, description: $description, cancelUrl: $cancelUrl, returnUrl: $returnUrl, total: $total, shippingMethods: $shippingMethods, shippingAddress: $shippingAddress, billingAddress: $billingAddress, totalAllowedOverCaptureAmount: $totalAllowedOverCaptureAmount)';
}