PPCheckoutConfigPatterns extension

Adds pattern-matching-related methods to PPCheckoutConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_PPCheckoutConfig value)) → TResult

Available on PPCheckoutConfig, provided by the PPCheckoutConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PPCheckoutConfig value)?) → TResult?

Available on PPCheckoutConfig, provided by the PPCheckoutConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PPCheckoutConfig value)?, {required TResult orElse()}) → TResult

Available on PPCheckoutConfig, provided by the PPCheckoutConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String clientId, String returnUrl, PPEnvironment environment, PPCurrencyCode? currencyCode, PPUserAction? userAction)?, {required TResult orElse()}) → TResult

Available on PPCheckoutConfig, provided by the PPCheckoutConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String clientId, String returnUrl, PPEnvironment environment, PPCurrencyCode? currencyCode, PPUserAction? userAction)) → TResult

Available on PPCheckoutConfig, provided by the PPCheckoutConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String clientId, String returnUrl, PPEnvironment environment, PPCurrencyCode? currencyCode, PPUserAction? userAction)?) → TResult?

Available on PPCheckoutConfig, provided by the PPCheckoutConfigPatterns extension

A variant of when that fallback to returning null