PPItem class abstract
Use for Cart Items
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
-
copyWith
→ $PPItemCopyWith<
PPItem> -
Create a copy of PPItem
with the given fields replaced by the non-null parameter values.
no setterinherited
- description → String?
-
no setterinherited
- details → dynamic
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
no setterinherited
- quantity → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → PPAmount?
-
no setterinherited
- unitPrice → PPAmount?
-
no setterinherited
Methods
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
map<
TResult extends Object?> (TResult $default(_PPItem value)) → TResult -
Available on PPItem, provided by the PPItemPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_PPItem value)?) → TResult? -
Available on PPItem, provided by the PPItemPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_PPItem value)?, {required TResult orElse()}) → TResult -
Available on PPItem, provided by the PPItemPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? description, String? name, PPAmount? unitPrice, int? quantity, PPAmount? total, dynamic details)?, {required TResult orElse()}) → TResult -
Available on PPItem, provided by the PPItemPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PPItem to a JSON map.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
when<
TResult extends Object?> (TResult $default(String? description, String? name, PPAmount? unitPrice, int? quantity, PPAmount? total, dynamic details)) → TResult -
Available on PPItem, provided by the PPItemPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? description, String? name, PPAmount? unitPrice, int? quantity, PPAmount? total, dynamic details)?) → TResult? -
Available on PPItem, provided by the PPItemPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited