PPOptionsPatterns extension

Adds pattern-matching-related methods to PPOptions.

on

Methods

map<TResult extends Object?>(TResult $default(_PPOptions value)) → TResult

Available on PPOptions, provided by the PPOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PPOptions value)?) → TResult?

Available on PPOptions, provided by the PPOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PPOptions value)?, {required TResult orElse()}) → TResult

Available on PPOptions, provided by the PPOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, bool selected, PPShippingType? type, PPUnitAmount? unitAmount)?, {required TResult orElse()}) → TResult

Available on PPOptions, provided by the PPOptionsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String id, bool selected, PPShippingType? type, PPUnitAmount? unitAmount)) → TResult

Available on PPOptions, provided by the PPOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, bool selected, PPShippingType? type, PPUnitAmount? unitAmount)?) → TResult?

Available on PPOptions, provided by the PPOptionsPatterns extension

A variant of when that fallback to returning null