PPOrderAddress class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

PPOrderAddress({@JsonKey.new(name: 'address_line_1') String? addressLine1, @JsonKey.new(name: 'address_line_2') String? addressLine2, @JsonKey.new(name: 'admin_area_1') String? adminArea1, @JsonKey.new(name: 'admin_area_2') String? adminArea2, String? postalCode, String? countryCode})
const
factory
PPOrderAddress.fromJson(Map<String, dynamic> json)
factory

Properties

addressLine1 String?
no setterinherited
addressLine2 String?
no setterinherited
adminArea1 String?
state or province like "CA" or "California"
no setterinherited
adminArea2 String?
city like "San Francisco"
no setterinherited
copyWith → $PPOrderAddressCopyWith<PPOrderAddress>
Create a copy of PPOrderAddress with the given fields replaced by the non-null parameter values.
no setterinherited
countryCode String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
postalCode String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
map<TResult extends Object?>(TResult $default(_PPOrderAddress value)) → TResult

Available on PPOrderAddress, provided by the PPOrderAddressPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PPOrderAddress value)?) → TResult?

Available on PPOrderAddress, provided by the PPOrderAddressPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PPOrderAddress value)?, {required TResult orElse()}) → TResult

Available on PPOrderAddress, provided by the PPOrderAddressPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? addressLine1, String? addressLine2, String? adminArea1, String? adminArea2, String? postalCode, String? countryCode)?, {required TResult orElse()}) → TResult

Available on PPOrderAddress, provided by the PPOrderAddressPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toJson() Map<String, dynamic>
Serializes this PPOrderAddress to a JSON map.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
when<TResult extends Object?>(TResult $default(String? addressLine1, String? addressLine2, String? adminArea1, String? adminArea2, String? postalCode, String? countryCode)) → TResult

Available on PPOrderAddress, provided by the PPOrderAddressPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? addressLine1, String? addressLine2, String? adminArea1, String? adminArea2, String? postalCode, String? countryCode)?) → TResult?

Available on PPOrderAddress, provided by the PPOrderAddressPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited