PPOrderAmount class abstract

Available extensions
Annotations
  • @freezed

Constructors

PPOrderAmount({required PPCurrencyCode currencyCode, required String value})
const
factory
PPOrderAmount.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PPOrderAmountCopyWith<PPOrderAmount>
Create a copy of PPOrderAmount with the given fields replaced by the non-null parameter values.
no setterinherited
currencyCode PPCurrencyCode
The three-character ISO-4217 currency code that identifies the currency. See PPCurrencyCode.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value, which might be:
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PPOrderAmount value)) → TResult

Available on PPOrderAmount, provided by the PPOrderAmountPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PPOrderAmount value)?) → TResult?

Available on PPOrderAmount, provided by the PPOrderAmountPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PPOrderAmount value)?, {required TResult orElse()}) → TResult

Available on PPOrderAmount, provided by the PPOrderAmountPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(PPCurrencyCode currencyCode, String value)?, {required TResult orElse()}) → TResult

Available on PPOrderAmount, provided by the PPOrderAmountPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PPOrderAmount to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(PPCurrencyCode currencyCode, String value)) → TResult

Available on PPOrderAmount, provided by the PPOrderAmountPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(PPCurrencyCode currencyCode, String value)?) → TResult?

Available on PPOrderAmount, provided by the PPOrderAmountPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited