PPOrderAppContext class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

PPOrderAppContext({String? returnUrl, String? cancelUrl, String? brandName, String? locale, String? landingPage, PPShippingPreference? shippingPreference, PPUserAction? userAction})
const
factory
PPOrderAppContext.fromJson(Map<String, dynamic> json)
factory

Properties

brandName String?
no setterinherited
cancelUrl String?
no setterinherited
copyWith → $PPOrderAppContextCopyWith<PPOrderAppContext>
Create a copy of PPOrderAppContext with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
landingPage String?
no setterinherited
locale String?
no setterinherited
returnUrl String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingPreference PPShippingPreference?
no setterinherited
userAction PPUserAction?
no setterinherited

Methods

debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
map<TResult extends Object?>(TResult $default(_PPOrderAppContext value)) → TResult

Available on PPOrderAppContext, provided by the PPOrderAppContextPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PPOrderAppContext value)?) → TResult?

Available on PPOrderAppContext, provided by the PPOrderAppContextPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PPOrderAppContext value)?, {required TResult orElse()}) → TResult

Available on PPOrderAppContext, provided by the PPOrderAppContextPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? returnUrl, String? cancelUrl, String? brandName, String? locale, String? landingPage, PPShippingPreference? shippingPreference, PPUserAction? userAction)?, {required TResult orElse()}) → TResult

Available on PPOrderAppContext, provided by the PPOrderAppContextPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toJson() Map<String, dynamic>
Serializes this PPOrderAppContext to a JSON map.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
when<TResult extends Object?>(TResult $default(String? returnUrl, String? cancelUrl, String? brandName, String? locale, String? landingPage, PPShippingPreference? shippingPreference, PPUserAction? userAction)) → TResult

Available on PPOrderAppContext, provided by the PPOrderAppContextPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? returnUrl, String? cancelUrl, String? brandName, String? locale, String? landingPage, PPShippingPreference? shippingPreference, PPUserAction? userAction)?) → TResult?

Available on PPOrderAppContext, provided by the PPOrderAppContextPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited