PPPurchaseUnitPatterns extension

Adds pattern-matching-related methods to PPPurchaseUnit.

on

Methods

map<TResult extends Object?>(TResult $default(_PPPurchaseUnit value)) → TResult

Available on PPPurchaseUnit, provided by the PPPurchaseUnitPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PPPurchaseUnit value)?) → TResult?

Available on PPPurchaseUnit, provided by the PPPurchaseUnitPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PPPurchaseUnit value)?, {required TResult orElse()}) → TResult

Available on PPPurchaseUnit, provided by the PPPurchaseUnitPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? referenceId, String? invoiceId, String? customId, String? softDescriptor, PPShipping? shipping, List<PPItems>? items, PPPayee? payee, PPOrderAmount orderAmount)?, {required TResult orElse()}) → TResult

Available on PPPurchaseUnit, provided by the PPPurchaseUnitPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? referenceId, String? invoiceId, String? customId, String? softDescriptor, PPShipping? shipping, List<PPItems>? items, PPPayee? payee, PPOrderAmount orderAmount)) → TResult

Available on PPPurchaseUnit, provided by the PPPurchaseUnitPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? referenceId, String? invoiceId, String? customId, String? softDescriptor, PPShipping? shipping, List<PPItems>? items, PPPayee? payee, PPOrderAmount orderAmount)?) → TResult?

Available on PPPurchaseUnit, provided by the PPPurchaseUnitPatterns extension

A variant of when that fallback to returning null