PPShippingMethodsPatterns extension

Adds pattern-matching-related methods to PPShippingMethods.

on

Methods

map<TResult extends Object?>(TResult $default(_PPShippingMethods value)) → TResult

Available on PPShippingMethods, provided by the PPShippingMethodsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PPShippingMethods value)?) → TResult?

Available on PPShippingMethods, provided by the PPShippingMethodsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PPShippingMethods value)?, {required TResult orElse()}) → TResult

Available on PPShippingMethods, provided by the PPShippingMethodsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String label, bool selected, PPAmount? amount, PPShippingMethodType? type)?, {required TResult orElse()}) → TResult

Available on PPShippingMethods, provided by the PPShippingMethodsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String id, String label, bool selected, PPAmount? amount, PPShippingMethodType? type)) → TResult

Available on PPShippingMethods, provided by the PPShippingMethodsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String label, bool selected, PPAmount? amount, PPShippingMethodType? type)?) → TResult?

Available on PPShippingMethods, provided by the PPShippingMethodsPatterns extension

A variant of when that fallback to returning null