PPCart class abstract
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
-
PPCart({String? cartId, String? intent, PPBillingType? billingType, String? paymentId, String? billingToken, List<
PPItem> ? items, CartAmounts? amounts, String? description, @JsonKey.new(name: 'cancelUrl', readValue: _PPCartHelper.readUrl) String? cancelUrl, @JsonKey.new(name: 'returnUrl', readValue: _PPCartHelper.readUrl) String? returnUrl, PPAmount? total, List<PPShippingMethods> ? shippingMethods, PPCartAddress? shippingAddress, PPCartAddress? billingAddress, PPAmount? totalAllowedOverCaptureAmount}) -
constfactory
-
PPCart.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amounts → CartAmounts?
-
no setterinherited
- billingAddress → PPCartAddress?
-
no setterinherited
- billingToken → String?
-
no setterinherited
- billingType → PPBillingType?
-
no setterinherited
- cancelUrl → String?
-
no setterinherited
- cartId → String?
-
no setterinherited
-
copyWith
→ $PPCartCopyWith<
PPCart> -
Create a copy of PPCart
with the given fields replaced by the non-null parameter values.
no setterinherited
- description → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- intent → String?
-
no setterinherited
-
items
→ List<
PPItem> ? -
no setterinherited
- paymentId → String?
-
no setterinherited
- returnUrl → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingAddress → PPCartAddress?
-
no setterinherited
-
shippingMethods
→ List<
PPShippingMethods> ? -
no setterinherited
- total → PPAmount?
-
no setterinherited
- totalAllowedOverCaptureAmount → PPAmount?
-
no setterinherited
Methods
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
map<
TResult extends Object?> (TResult $default(_PPCart value)) → TResult -
Available on PPCart, provided by the PPCartPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_PPCart value)?) → TResult? -
Available on PPCart, provided by the PPCartPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_PPCart value)?, {required TResult orElse()}) → TResult -
Available on PPCart, provided by the PPCartPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? cartId, String? intent, PPBillingType? billingType, String? paymentId, String? billingToken, List< PPItem> ? items, CartAmounts? amounts, String? description, String? cancelUrl, String? returnUrl, PPAmount? total, List<PPShippingMethods> ? shippingMethods, PPCartAddress? shippingAddress, PPCartAddress? billingAddress, PPAmount? totalAllowedOverCaptureAmount)?, {required TResult orElse()}) → TResult -
Available on PPCart, provided by the PPCartPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PPCart to a JSON map.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
when<
TResult extends Object?> (TResult $default(String? cartId, String? intent, PPBillingType? billingType, String? paymentId, String? billingToken, List< PPItem> ? items, CartAmounts? amounts, String? description, String? cancelUrl, String? returnUrl, PPAmount? total, List<PPShippingMethods> ? shippingMethods, PPCartAddress? shippingAddress, PPCartAddress? billingAddress, PPAmount? totalAllowedOverCaptureAmount)) → TResult -
Available on PPCart, provided by the PPCartPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? cartId, String? intent, PPBillingType? billingType, String? paymentId, String? billingToken, List< PPItem> ? items, CartAmounts? amounts, String? description, String? cancelUrl, String? returnUrl, PPAmount? total, List<PPShippingMethods> ? shippingMethods, PPCartAddress? shippingAddress, PPCartAddress? billingAddress, PPAmount? totalAllowedOverCaptureAmount)?) → TResult? -
Available on PPCart, provided by the PPCartPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited